@@ -8,7 +8,7 @@ no warnings 'recursion';
 
 package XML::Compile::Schema::BuiltInTypes;
 use vars '$VERSION';
-$VERSION = '1.35';
+$VERSION = '1.36';
 
 use base 'Exporter';
 
@@ -306,7 +306,7 @@ $builtin_types{base64Binary} =
  { parse   => sub { eval { decode_base64 $_[0] } }
  , format  => sub { eval { encode_base64 $_[0] } }
  , check   => sub { !$@ }
- , example => 'VGVzdA=='
+ , example => 'decoded bytes'
  , extends => 'anyAtomicType'
  };
 
